nbxmpp.stringprepare.LookupTable

Package nbxmpp :: Module stringprepare :: Class LookupTable |
[hide private]
[frames] | no frames]

# Class LookupTable

source code

Nested Classes | [hide private]
| __implements__ Interface for character lookup classes

Instance Methods | [hide private]
__init__(self, table) | source code
lookup(self, c) | source code

Method Details | [hide private]

### __init__(self, table) (Constructor) | source code

### lookup(self, c) | source code